import fetch from 'node-fetch';

interface AssistantSettings {
  silence_timeout: number;
  // Add other settings as needed
}

let cachedSettings: AssistantSettings | null = null;

export const config = {
  voice360ApiKey: process.env.VOICE360_API_KEY || '',
  assistantId: process.env.ASSISTANT_ID || '',
  perfexCrmUrl: process.env.PERFEX_CRM_URL || '',
};

export async function fetchAssistantSettings(assistantId: string): Promise<AssistantSettings> {
  try {
    const url = new URL(`/admin/voice360/API/get_assistant_settings/${assistantId}`, config.perfexCrmUrl);
    
    console.log('Fetching assistant settings from:', url.toString());
    console.log('Using API Key:', config.voice360ApiKey);

    const response = await fetch(url.toString(), {
      headers: {
        'Accept': 'application/json',
        'X-Requested-With': 'XMLHttpRequest',
        'Authorization': `Bearer ${config.voice360ApiKey}`
      }
    });

   // console.log('Response status:', response.status);

    if (!response.ok) {
      const errorText = await response.text();
      console.error('Error response body:', errorText);
      throw new Error(`Failed to fetch assistant settings. Status: ${response.status}, Error: ${errorText}`);
    }

    const data = await response.json();
    console.log('Fetched assistant settings:', data);
    return {
      silence_timeout: data.silence_timeout || 30,
      // Add other settings as needed
    };
  } catch (error) {
    console.error('Error fetching assistant settings:', error);
    // Return default settings instead of throwing
    return {
      silence_timeout: 30,
      // Add other default settings as needed
    };
  }
}

export function updateCachedSettings(newSettings: AssistantSettings) {
  cachedSettings = newSettings;
}

export function getCachedSettings(): AssistantSettings | null {
  return cachedSettings;
}

export default config;
